@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2007 Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2007 The xmlm programmers. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   xmlm v1.3.0
   ---------------------------------------------------------------------------*)
 
 module Std_string = String
@@ -1125,7 +1124,7 @@ module String = struct
   let empty = ""
   let length = String.length
   let append = ( ^ )
-  let lowercase = String.lowercase
+  let lowercase = String.lowercase_ascii
   let iter f s =
     let len = Std_string.length s in
     let pos = ref ~-1 in
@@ -1199,7 +1198,7 @@ let pp_signal ppf = function
 | `Dtd dtd -> pp ppf "@[`Dtd %a@]" pp_dtd dtd
 
 (*----------------------------------------------------------------------------
-   Copyright (c) 2007 Daniel C. Bünzli
+   Copyright (c) 2007 The xmlm programmers
 
    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted, provided that the above
