@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
-   Copyright (c) 2007 Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2007 The xmlm programmers. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   xmlm v1.3.0
   ---------------------------------------------------------------------------*)
 
 let str = Printf.sprintf
@@ -168,7 +167,7 @@ let process signals tree enc strip eref ns xhtml parse_only outline indent
   in
   List.iter f files
 
-let encoding_of_str enc = match (String.lowercase enc) with
+let encoding_of_str enc = match (String.lowercase_ascii enc) with
 | "" -> None
 | "utf-8" | "utf8" | "utf_8" -> Some `UTF_8
 | "utf-16" | "utf16" | "utf_16" -> Some `UTF_16
@@ -233,7 +232,7 @@ let main () =
 let () = main ()
 
 (*---------------------------------------------------------------------------
-   Copyright (c) 2007 Daniel C. Bünzli
+   Copyright (c) 2007 The xmlm programmers
 
    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted, provided that the above
